@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2009-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -20,14 +19,28 @@ Python implementation of a part of Dan Bernstein's ftpparse library.
 See also http://cr.yp.to/ftpparse.html
 """
 
-months = ("jan", "feb", "mar", "apr", "may", "jun", "jul", "aug", "sep",
-          "oct", "nov", "dec")
-def ismonth (txt):
+months = (
+    "jan",
+    "feb",
+    "mar",
+    "apr",
+    "may",
+    "jun",
+    "jul",
+    "aug",
+    "sep",
+    "oct",
+    "nov",
+    "dec",
+)
+
+
+def ismonth(txt):
     """Check if given text is a month name."""
     return txt.lower() in months
 
 
-def ftpparse (line):
+def ftpparse(line):
     """Parse a FTP list line into a dictionary with attributes:
     name - name of file (string)
     trycwd - False if cwd is definitely pointless, True otherwise
@@ -61,7 +74,7 @@ def ftpparse (line):
     # Also produced by Microsoft's FTP servers for Windows:
     # "----------   1 owner    group         1803128 Jul 10 10:18 ls-lR.Z"
     # "d---------   1 owner    group               0 May  9 19:45 Softlib"
-    # Also WFTPD for MSDOS:
+    # Also WFTPD for MS-DOS:
     # "-rwxrwxrwx   1 noone    nogroup      322 Aug 19  1996 message.ftp"
     # Also NetWare:
     # "d [R----F--] supervisor            512       Jan 16 18:53    login"
@@ -79,20 +92,20 @@ def ftpparse (line):
         parts = line.split()
         if len(parts) < 7:
             return None
-        del parts[0] # skip permissions
+        del parts[0]  # skip permissions
         if parts[0] != 'folder':
-            del parts[0] # skip nlink
-        del parts[0] # skip uid
-        del parts[0] # skip gid or size
+            del parts[0]  # skip nlink
+        del parts[0]  # skip uid
+        del parts[0]  # skip gid or size
         if not ismonth(parts[0]):
-            del parts[0] # skip size
+            del parts[0]  # skip size
         if not ismonth(parts[0]):
             return None
-        del parts[0] # skip month
-        del parts[0] # skip day
+        del parts[0]  # skip month
+        del parts[0]  # skip day
         if not parts:
             return None
-        del parts[0] # skip year or time
+        del parts[0]  # skip year or time
         name = " ".join(parts)
         # resolve links
         if line[0] == 'l' and ' -> ' in name:
@@ -119,7 +132,7 @@ def ftpparse (line):
         info["name"] = name
         return info
 
-    # MSDOS format
+    # MS-DOS format
     # 04-27-00  09:09PM       <DIR>          licensed
     # 07-18-00  10:16AM       <DIR>          pub
     # 04-14-00  03:47PM                  589 readme.htm
