@@ -1,5 +1,4 @@
-# -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2010 Bastian Kleineidam
+# Copyright (C) 2000-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,56 +16,62 @@
 """
 A gml logger.
 """
-from .graph import GraphLogger
+from .graph import _GraphLogger
 
 
-class GMLLogger (GraphLogger):
+class GMLLogger(_GraphLogger):
     """GML means Graph Modeling Language. Use a GML tool to see
     the sitemap graph."""
 
-    def start_output (self):
+    LoggerName = 'gml'
+
+    LoggerArgs = {
+        "filename": "linkchecker-out.gml",
+    }
+
+    def start_output(self):
         """Write start of checking info as gml comment."""
-        super(GMLLogger, self).start_output()
+        super().start_output()
         if self.has_part("intro"):
             self.write_intro()
             self.writeln()
-        self.writeln(u"graph [")
-        self.writeln(u"  directed 1")
+        self.writeln("graph [")
+        self.writeln("  directed 1")
         self.flush()
 
-    def comment (self, s, **args):
+    def comment(self, s, **args):
         """Write GML comment."""
-        self.writeln(s=u'comment "%s"' % s, **args)
+        self.writeln(s='comment "%s"' % s, **args)
 
-    def log_url (self, url_data):
+    def log_url(self, url_data):
         """Write one node."""
         node = self.get_node(url_data)
         if node:
-            self.writeln(u"  node [")
-            self.writeln(u"    id     %d" % node["id"])
-            self.writeln(u'    label  "%s"' % node["label"])
+            self.writeln("  node [")
+            self.writeln("    id     %d" % node["id"])
+            self.writeln('    label  "%s"' % node["label"])
             if self.has_part("realurl"):
-                self.writeln(u'    url  "%s"' % node["url"])
+                self.writeln('    url  "%s"' % node["url"])
             if node["dltime"] >= 0 and self.has_part("dltime"):
-                self.writeln(u"    dltime %d" % node["dltime"])
-            if node["dlsize"] >= 0 and self.has_part("dlsize"):
-                self.writeln(u"    dlsize %d" % node["dlsize"])
+                self.writeln("    dltime %d" % node["dltime"])
+            if node["size"] >= 0 and self.has_part("dlsize"):
+                self.writeln("    size %d" % node["size"])
             if node["checktime"] and self.has_part("checktime"):
-                self.writeln(u"    checktime %d" % node["checktime"])
+                self.writeln("    checktime %d" % node["checktime"])
             if self.has_part("extern"):
-                self.writeln(u"    extern %d" % node["extern"])
-            self.writeln(u"  ]")
+                self.writeln("    extern %d" % node["extern"])
+            self.writeln("  ]")
 
-    def write_edge (self, node):
+    def write_edge(self, node):
         """Write one edge."""
-        self.writeln(u"  edge [")
-        self.writeln(u'    label  "%s"' % node["edge"])
-        self.writeln(u"    source %d" % self.nodes[node["parent_url"]]["id"])
-        self.writeln(u"    target %d" % node["id"])
+        self.writeln("  edge [")
+        self.writeln('    label  "%s"' % node["edge"])
+        self.writeln("    source %d" % self.nodes[node["parent_url"]]["id"])
+        self.writeln("    target %d" % node["id"])
         if self.has_part("result"):
-            self.writeln(u"    valid  %d" % node["valid"])
-        self.writeln(u"  ]")
+            self.writeln("    valid  %d" % node["valid"])
+        self.writeln("  ]")
 
-    def end_graph (self):
+    def end_graph(self):
         """Write end of graph marker."""
-        self.writeln(u"]")
+        self.writeln("]")
