@@ -19,7 +19,6 @@ Store and retrieve country names for IPs.
 from . import _ConnectionPlugin
 import os
 import sys
-import socket
 from ..lock import get_lock
 from ..decorators import synchronized
 from .. import log, LOG_PLUGIN
@@ -70,6 +69,7 @@ def get_geoip_dat():
 # try importing both the C-library GeoIP and the pure-python pygeoip
 geoip_dat = get_geoip_dat()
 geoip = None
+geoip_error = None
 if geoip_dat:
     try:
         import GeoIP
@@ -105,7 +105,7 @@ def get_location(host):
         return None
     try:
         record = get_geoip_record(host)
-    except (geoip_error, socket.error):
+    except (geoip_error, OSError):
         log.debug(LOG_PLUGIN, "Geoip error for %r", host, exception=True)
         # ignore lookup errors
         return None
